@@ -14,6 +14,8 @@ BEGIN {
 
 use Exporter qw{ import };
 
+use constant CODE_REF	=> ref sub {};
+
 {
     my @const = qw{
         defaultFlavor
@@ -49,7 +51,7 @@ use Exporter qw{ import };
     our @EXPORT = @funcs;	## no critic (ProhibitAutomaticExportation)
 }
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 our $XS_VERSION = $VERSION;
 our $ALPHA_VERSION = $VERSION;
 $VERSION =~ s/_//g;
@@ -274,7 +276,7 @@ sub set {
 	$attr{$name}
 	    or croak "Attribute '$name' is read-only";
 	my $ref = ref $attr{$name};
-	if ($ref eq 'CODE') {
+	if ( CODE_REF eq $ref ) {
 	    $hash->{$name} = $attr{$name}->($self, $name, shift @args);
 	} else {
 	    $hash->{$name} = shift @args;
@@ -1130,7 +1132,7 @@ Thomas R. Wyant, III, F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008, 2011-2017 by Thomas R. Wyant, III
+Copyright (C) 2008, 2011-2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
